@@ -235,3 +235,9 @@ void
 glmc_vec2_complex_conjugate(vec2 a, vec2 dest) {
   glm_vec2_complex_conjugate(a, dest);
 }
+
+CGLM_EXPORT
+void
+glmc_vec2_make(float * __restrict src, vec2 dest) {
+  glm_vec2_make(src, dest);
+}
