@@ -1729,3 +1729,24 @@ TEST_IMPL(GLM_PREFIX, vec3_sqrt) {
 
   TEST_SUCCESS
 }
+
+TEST_IMPL(GLM_PREFIX, vec3_make) {
+  float src[9] = {
+    7.2f, 1.0f, 5.8f,
+    2.5f, 6.1f, 9.9f,
+    17.7f, 4.3f, 3.2f
+  };
+  vec3 dest[3];
+
+  float *srcp = src;
+  unsigned int i, j;
+
+  for (i = 0, j = 0; i < sizeof(src) / sizeof(float); i+=3,j++) {
+    GLM(vec3_make)(srcp + i, dest[j]);
+    ASSERT(test_eq(src[ i ], dest[j][0]));
+    ASSERT(test_eq(src[i+1], dest[j][1]));
+    ASSERT(test_eq(src[i+2], dest[j][2]));
+  }
+
+  TEST_SUCCESS
+}
