@@ -124,6 +124,7 @@ TEST_DECLARE(glm_mat4_inv_precise)
 TEST_DECLARE(glm_mat4_swap_col)
 TEST_DECLARE(glm_mat4_swap_row)
 TEST_DECLARE(glm_mat4_rmc)
+TEST_DECLARE(glm_mat4_make)
 
 TEST_DECLARE(glmc_mat4_ucopy)
 TEST_DECLARE(glmc_mat4_copy)
@@ -150,6 +151,43 @@ TEST_DECLARE(glmc_mat4_inv_fast)
 TEST_DECLARE(glmc_mat4_swap_col)
 TEST_DECLARE(glmc_mat4_swap_row)
 TEST_DECLARE(glmc_mat4_rmc)
+TEST_DECLARE(glmc_mat4_make)
+
+TEST_DECLARE(MACRO_GLM_MAT4X2_ZERO_INIT)
+TEST_DECLARE(MACRO_GLM_MAT4X2_ZERO)
+TEST_DECLARE(glm_mat4x2_copy)
+TEST_DECLARE(glm_mat4x2_zero)
+TEST_DECLARE(glm_mat4x2_make)
+TEST_DECLARE(glm_mat4x2_mul)
+TEST_DECLARE(glm_mat4x2_mulv)
+TEST_DECLARE(glm_mat4x2_transpose)
+TEST_DECLARE(glm_mat4x2_scale)
+
+TEST_DECLARE(glmc_mat4x2_copy)
+TEST_DECLARE(glmc_mat4x2_zero)
+TEST_DECLARE(glmc_mat4x2_make)
+TEST_DECLARE(glmc_mat4x2_mul)
+TEST_DECLARE(glmc_mat4x2_mulv)
+TEST_DECLARE(glmc_mat4x2_transpose)
+TEST_DECLARE(glmc_mat4x2_scale)
+
+TEST_DECLARE(MACRO_GLM_MAT4X3_ZERO_INIT)
+TEST_DECLARE(MACRO_GLM_MAT4X3_ZERO)
+TEST_DECLARE(glm_mat4x3_copy)
+TEST_DECLARE(glm_mat4x3_zero)
+TEST_DECLARE(glm_mat4x3_make)
+TEST_DECLARE(glm_mat4x3_mul)
+TEST_DECLARE(glm_mat4x3_mulv)
+TEST_DECLARE(glm_mat4x3_transpose)
+TEST_DECLARE(glm_mat4x3_scale)
+
+TEST_DECLARE(glmc_mat4x3_copy)
+TEST_DECLARE(glmc_mat4x3_zero)
+TEST_DECLARE(glmc_mat4x3_make)
+TEST_DECLARE(glmc_mat4x3_mul)
+TEST_DECLARE(glmc_mat4x3_mulv)
+TEST_DECLARE(glmc_mat4x3_transpose)
+TEST_DECLARE(glmc_mat4x3_scale)
 
 /* mat3 */
 TEST_DECLARE(glm_mat3_copy)
@@ -168,6 +206,7 @@ TEST_DECLARE(glm_mat3_inv)
 TEST_DECLARE(glm_mat3_swap_col)
 TEST_DECLARE(glm_mat3_swap_row)
 TEST_DECLARE(glm_mat3_rmc)
+TEST_DECLARE(glm_mat3_make)
 
 TEST_DECLARE(glmc_mat3_copy)
 TEST_DECLARE(glmc_mat3_identity)
@@ -185,6 +224,31 @@ TEST_DECLARE(glmc_mat3_inv)
 TEST_DECLARE(glmc_mat3_swap_col)
 TEST_DECLARE(glmc_mat3_swap_row)
 TEST_DECLARE(glmc_mat3_rmc)
+TEST_DECLARE(glmc_mat3_make)
+
+TEST_DECLARE(MACRO_GLM_MAT3X2_ZERO_INIT)
+TEST_DECLARE(MACRO_GLM_MAT3X2_ZERO)
+TEST_DECLARE(glm_mat3x2_copy)
+TEST_DECLARE(glm_mat3x2_zero)
+TEST_DECLARE(glm_mat3x2_make)
+TEST_DECLARE(glm_mat3x2_mul)
+TEST_DECLARE(glm_mat3x2_mulv)
+TEST_DECLARE(glm_mat3x2_transpose)
+TEST_DECLARE(glm_mat3x2_scale)
+
+TEST_DECLARE(glmc_mat3x2_copy)
+TEST_DECLARE(glmc_mat3x2_zero)
+TEST_DECLARE(glmc_mat3x2_make)
+TEST_DECLARE(glmc_mat3x2_mul)
+TEST_DECLARE(glmc_mat3x2_mulv)
+TEST_DECLARE(glmc_mat3x2_transpose)
+TEST_DECLARE(glmc_mat3x2_scale)
+
+TEST_DECLARE(MACRO_GLM_MAT3X4_ZERO_INIT)
+TEST_DECLARE(MACRO_GLM_MAT3X4_ZERO)
+TEST_DECLARE(glm_mat3x4_make)
+
+TEST_DECLARE(glmc_mat3x4_make)
 
 TEST_DECLARE(MACRO_GLM_MAT2_IDENTITY_INIT)
 TEST_DECLARE(MACRO_GLM_MAT2_ZERO_INIT)
@@ -205,6 +269,7 @@ TEST_DECLARE(glm_mat2_inv)
 TEST_DECLARE(glm_mat2_swap_col)
 TEST_DECLARE(glm_mat2_swap_row)
 TEST_DECLARE(glm_mat2_rmc)
+TEST_DECLARE(glm_mat2_make)
 
 TEST_DECLARE(glmc_mat2_copy)
 TEST_DECLARE(glmc_mat2_identity)
@@ -221,6 +286,43 @@ TEST_DECLARE(glmc_mat2_inv)
 TEST_DECLARE(glmc_mat2_swap_col)
 TEST_DECLARE(glmc_mat2_swap_row)
 TEST_DECLARE(glmc_mat2_rmc)
+TEST_DECLARE(glmc_mat2_make)
+
+TEST_DECLARE(MACRO_GLM_MAT2X3_ZERO_INIT)
+TEST_DECLARE(MACRO_GLM_MAT2X3_ZERO)
+TEST_DECLARE(glm_mat2x3_copy)
+TEST_DECLARE(glm_mat2x3_zero)
+TEST_DECLARE(glm_mat2x3_make)
+TEST_DECLARE(glm_mat2x3_mul)
+TEST_DECLARE(glm_mat2x3_mulv)
+TEST_DECLARE(glm_mat2x3_transpose)
+TEST_DECLARE(glm_mat2x3_scale)
+
+TEST_DECLARE(glmc_mat2x3_copy)
+TEST_DECLARE(glmc_mat2x3_zero)
+TEST_DECLARE(glmc_mat2x3_make)
+TEST_DECLARE(glmc_mat2x3_mul)
+TEST_DECLARE(glmc_mat2x3_mulv)
+TEST_DECLARE(glmc_mat2x3_transpose)
+TEST_DECLARE(glmc_mat2x3_scale)
+
+TEST_DECLARE(MACRO_GLM_MAT2X4_ZERO_INIT)
+TEST_DECLARE(MACRO_GLM_MAT2X4_ZERO)
+TEST_DECLARE(glm_mat2x4_copy)
+TEST_DECLARE(glm_mat2x4_zero)
+TEST_DECLARE(glm_mat2x4_make)
+TEST_DECLARE(glm_mat2x4_mul)
+TEST_DECLARE(glm_mat2x4_mulv)
+TEST_DECLARE(glm_mat2x4_transpose)
+TEST_DECLARE(glm_mat2x4_scale)
+
+TEST_DECLARE(glmc_mat2x4_copy)
+TEST_DECLARE(glmc_mat2x4_zero)
+TEST_DECLARE(glmc_mat2x4_make)
+TEST_DECLARE(glmc_mat2x4_mul)
+TEST_DECLARE(glmc_mat2x4_mulv)
+TEST_DECLARE(glmc_mat2x4_transpose)
+TEST_DECLARE(glmc_mat2x4_scale)
 
 /* camera (incl [LR]H cross [NZ]O) */
 TEST_DECLARE(glm_perspective_lh_zo)
@@ -305,6 +407,7 @@ TEST_DECLARE(glm_quat_rotate)
 TEST_DECLARE(glm_quat_rotate_at)
 TEST_DECLARE(glm_quat_rotate_atm)
 TEST_DECLARE(glm_quat_from_vecs)
+TEST_DECLARE(glm_quat_make)
 
 TEST_DECLARE(glmc_quat_identity)
 TEST_DECLARE(glmc_quat_identity_array)
@@ -343,6 +446,7 @@ TEST_DECLARE(glmc_quat_rotate)
 TEST_DECLARE(glmc_quat_rotate_at)
 TEST_DECLARE(glmc_quat_rotate_atm)
 TEST_DECLARE(glmc_quat_from_vecs)
+TEST_DECLARE(glmc_quat_make)
 
 /* bezier */
 TEST_DECLARE(bezier)
@@ -390,6 +494,7 @@ TEST_DECLARE(glm_vec2_abs)
 TEST_DECLARE(glm_vec2_lerp)
 TEST_DECLARE(glm_vec2_complex_mul)
 TEST_DECLARE(glm_vec2_complex_div)
+TEST_DECLARE(glm_vec2_make)
 
 TEST_DECLARE(glmc_vec2)
 TEST_DECLARE(glmc_vec2_copy)
@@ -428,6 +533,7 @@ TEST_DECLARE(glmc_vec2_abs)
 TEST_DECLARE(glmc_vec2_lerp)
 TEST_DECLARE(glmc_vec2_complex_mul)
 TEST_DECLARE(glmc_vec2_complex_div)
+TEST_DECLARE(glmc_vec2_make)
 
 /* vec3 */
 TEST_DECLARE(MACRO_GLM_VEC3_ONE_INIT)
@@ -523,6 +629,7 @@ TEST_DECLARE(glm_vec3_abs)
 TEST_DECLARE(glm_vec3_fract)
 TEST_DECLARE(glm_vec3_hadd)
 TEST_DECLARE(glm_vec3_sqrt)
+TEST_DECLARE(glm_vec3_make)
 
 TEST_DECLARE(glmc_vec3)
 TEST_DECLARE(glmc_vec3_copy)
@@ -592,6 +699,7 @@ TEST_DECLARE(glmc_vec3_abs)
 TEST_DECLARE(glmc_vec3_fract)
 TEST_DECLARE(glmc_vec3_hadd)
 TEST_DECLARE(glmc_vec3_sqrt)
+TEST_DECLARE(glmc_vec3_make)
 
 /* vec4 */
 TEST_DECLARE(MACRO_GLM_VEC4_ONE_INIT)
@@ -673,6 +781,7 @@ TEST_DECLARE(glm_vec4_abs)
 TEST_DECLARE(glm_vec4_fract)
 TEST_DECLARE(glm_vec4_hadd)
 TEST_DECLARE(glm_vec4_sqrt)
+TEST_DECLARE(glm_vec4_make)
 
 TEST_DECLARE(glmc_vec4)
 TEST_DECLARE(glmc_vec4_copy3)
@@ -738,6 +847,7 @@ TEST_DECLARE(glmc_vec4_abs)
 TEST_DECLARE(glmc_vec4_fract)
 TEST_DECLARE(glmc_vec4_hadd)
 TEST_DECLARE(glmc_vec4_sqrt)
+TEST_DECLARE(glmc_vec4_make)
 
 /* ivec2 */
 TEST_DECLARE(glm_ivec2)
@@ -843,10 +953,22 @@ TEST_DECLARE(glmc_ivec4_clamp)
 TEST_DECLARE(glmc_ivec4_abs)
 
 /* structs */
+TEST_DECLARE(mat2x3s_zero_init)
+TEST_DECLARE(mat2x3s_zero)
+TEST_DECLARE(mat2x4s_zero_init)
+TEST_DECLARE(mat2x4s_zero)
 TEST_DECLARE(mat3s_identity_init)
 TEST_DECLARE(mat3s_zero_init)
+TEST_DECLARE(mat3x2s_zero_init)
+TEST_DECLARE(mat3x2s_zero)
+TEST_DECLARE(mat3x4s_zero_init)
+TEST_DECLARE(mat3x4s_zero)
 TEST_DECLARE(mat4s_identity_init)
 TEST_DECLARE(mat4s_zero_init)
+TEST_DECLARE(mat4x2s_zero_init)
+TEST_DECLARE(mat4x2s_zero)
+TEST_DECLARE(mat4x3s_zero_init)
+TEST_DECLARE(mat4x3s_zero)
 TEST_DECLARE(quats_zero_init)
 TEST_DECLARE(vec3s_one_init)
 TEST_DECLARE(vec3s_zero_init)
@@ -965,6 +1087,7 @@ TEST_LIST {
   TEST_ENTRY(glm_mat4_swap_col)
   TEST_ENTRY(glm_mat4_swap_row)
   TEST_ENTRY(glm_mat4_rmc)
+  TEST_ENTRY(glm_mat4_make)
   
   TEST_ENTRY(glmc_mat4_ucopy)
   TEST_ENTRY(glmc_mat4_copy)
@@ -991,7 +1114,44 @@ TEST_LIST {
   TEST_ENTRY(glmc_mat4_swap_col)
   TEST_ENTRY(glmc_mat4_swap_row)
   TEST_ENTRY(glmc_mat4_rmc)
-  
+  TEST_ENTRY(glmc_mat4_make)
+
+  TEST_ENTRY(MACRO_GLM_MAT4X2_ZERO_INIT)
+  TEST_ENTRY(MACRO_GLM_MAT4X2_ZERO)
+  TEST_ENTRY(glm_mat4x2_copy)
+  TEST_ENTRY(glm_mat4x2_zero)
+  TEST_ENTRY(glm_mat4x2_make)
+  TEST_ENTRY(glm_mat4x2_mul)
+  TEST_ENTRY(glm_mat4x2_mulv)
+  TEST_ENTRY(glm_mat4x2_transpose)
+  TEST_ENTRY(glm_mat4x2_scale)
+
+  TEST_ENTRY(glmc_mat4x2_copy)
+  TEST_ENTRY(glmc_mat4x2_zero)
+  TEST_ENTRY(glmc_mat4x2_make)
+  TEST_ENTRY(glmc_mat4x2_mul)
+  TEST_ENTRY(glmc_mat4x2_mulv)
+  TEST_ENTRY(glmc_mat4x2_transpose)
+  TEST_ENTRY(glmc_mat4x2_scale)
+
+  TEST_ENTRY(MACRO_GLM_MAT4X3_ZERO_INIT)
+  TEST_ENTRY(MACRO_GLM_MAT4X3_ZERO)
+  TEST_ENTRY(glm_mat4x3_copy)
+  TEST_ENTRY(glm_mat4x3_zero)
+  TEST_ENTRY(glm_mat4x3_make)
+  TEST_ENTRY(glm_mat4x3_mul)
+  TEST_ENTRY(glm_mat4x3_mulv)
+  TEST_ENTRY(glm_mat4x3_transpose)
+  TEST_ENTRY(glm_mat4x3_scale)
+
+  TEST_ENTRY(glmc_mat4x3_copy)
+  TEST_ENTRY(glmc_mat4x3_zero)
+  TEST_ENTRY(glmc_mat4x3_make)
+  TEST_ENTRY(glmc_mat4x3_mul)
+  TEST_ENTRY(glmc_mat4x3_mulv)
+  TEST_ENTRY(glmc_mat4x3_transpose)
+  TEST_ENTRY(glmc_mat4x3_scale)
+
   /* mat3 */
   TEST_ENTRY(glm_mat3_copy)
   TEST_ENTRY(glm_mat3_identity)
@@ -1009,6 +1169,7 @@ TEST_LIST {
   TEST_ENTRY(glm_mat3_swap_col)
   TEST_ENTRY(glm_mat3_swap_row)
   TEST_ENTRY(glm_mat3_rmc)
+  TEST_ENTRY(glm_mat3_make)
 
   TEST_ENTRY(glmc_mat3_copy)
   TEST_ENTRY(glmc_mat3_identity)
@@ -1026,7 +1187,32 @@ TEST_LIST {
   TEST_ENTRY(glmc_mat3_swap_col)
   TEST_ENTRY(glmc_mat3_swap_row)
   TEST_ENTRY(glmc_mat3_rmc)
-  
+  TEST_ENTRY(glmc_mat3_make)
+
+  TEST_ENTRY(MACRO_GLM_MAT3X2_ZERO_INIT)
+  TEST_ENTRY(MACRO_GLM_MAT3X2_ZERO)
+  TEST_ENTRY(glm_mat3x2_copy)
+  TEST_ENTRY(glm_mat3x2_zero)
+  TEST_ENTRY(glm_mat3x2_make)
+  TEST_ENTRY(glm_mat3x2_mul)
+  TEST_ENTRY(glm_mat3x2_mulv)
+  TEST_ENTRY(glm_mat3x2_transpose)
+  TEST_ENTRY(glm_mat3x2_scale)
+
+  TEST_ENTRY(glmc_mat3x2_copy)
+  TEST_ENTRY(glmc_mat3x2_zero)
+  TEST_ENTRY(glmc_mat3x2_make)
+  TEST_ENTRY(glmc_mat3x2_mul)
+  TEST_ENTRY(glmc_mat3x2_mulv)
+  TEST_ENTRY(glmc_mat3x2_transpose)
+  TEST_ENTRY(glmc_mat3x2_scale)
+
+  TEST_ENTRY(MACRO_GLM_MAT3X4_ZERO_INIT)
+  TEST_ENTRY(MACRO_GLM_MAT3X4_ZERO)
+  TEST_ENTRY(glm_mat3x4_make)
+
+  TEST_ENTRY(glmc_mat3x4_make)
+
   TEST_ENTRY(MACRO_GLM_MAT2_IDENTITY_INIT)
   TEST_ENTRY(MACRO_GLM_MAT2_ZERO_INIT)
   TEST_ENTRY(MACRO_GLM_MAT2_IDENTITY)
@@ -1046,6 +1232,7 @@ TEST_LIST {
   TEST_ENTRY(glm_mat2_swap_col)
   TEST_ENTRY(glm_mat2_swap_row)
   TEST_ENTRY(glm_mat2_rmc)
+  TEST_ENTRY(glm_mat2_make)
 
   TEST_ENTRY(glmc_mat2_copy)
   TEST_ENTRY(glmc_mat2_identity)
@@ -1062,6 +1249,43 @@ TEST_LIST {
   TEST_ENTRY(glmc_mat2_swap_col)
   TEST_ENTRY(glmc_mat2_swap_row)
   TEST_ENTRY(glmc_mat2_rmc)
+  TEST_ENTRY(glmc_mat2_make)
+
+  TEST_ENTRY(MACRO_GLM_MAT2X3_ZERO_INIT)
+  TEST_ENTRY(MACRO_GLM_MAT2X3_ZERO)
+  TEST_ENTRY(glm_mat2x3_copy)
+  TEST_ENTRY(glm_mat2x3_zero)
+  TEST_ENTRY(glm_mat2x3_make)
+  TEST_ENTRY(glm_mat2x3_mul)
+  TEST_ENTRY(glm_mat2x3_mulv)
+  TEST_ENTRY(glm_mat2x3_transpose)
+  TEST_ENTRY(glm_mat2x3_scale)
+
+  TEST_ENTRY(glmc_mat2x3_copy)
+  TEST_ENTRY(glmc_mat2x3_zero)
+  TEST_ENTRY(glmc_mat2x3_make)
+  TEST_ENTRY(glmc_mat2x3_mul)
+  TEST_ENTRY(glmc_mat2x3_mulv)
+  TEST_ENTRY(glmc_mat2x3_transpose)
+  TEST_ENTRY(glmc_mat2x3_scale)
+
+  TEST_ENTRY(MACRO_GLM_MAT2X4_ZERO_INIT)
+  TEST_ENTRY(MACRO_GLM_MAT2X4_ZERO)
+  TEST_ENTRY(glm_mat2x4_copy)
+  TEST_ENTRY(glm_mat2x4_zero)
+  TEST_ENTRY(glm_mat2x4_make)
+  TEST_ENTRY(glm_mat2x4_mul)
+  TEST_ENTRY(glm_mat2x4_mulv)
+  TEST_ENTRY(glm_mat2x4_transpose)
+  TEST_ENTRY(glm_mat2x4_scale)
+
+  TEST_ENTRY(glm_mat2x4_copy)
+  TEST_ENTRY(glm_mat2x4_zero)
+  TEST_ENTRY(glm_mat2x4_make)
+  TEST_ENTRY(glm_mat2x4_mul)
+  TEST_ENTRY(glm_mat2x4_mulv)
+  TEST_ENTRY(glm_mat2x4_transpose)
+  TEST_ENTRY(glm_mat2x4_scale)
 
   /* camera (incl [LR]H cross [NZ]O) */
   TEST_ENTRY(glm_perspective_lh_zo)
@@ -1146,6 +1370,7 @@ TEST_LIST {
   TEST_ENTRY(glm_quat_rotate_at)
   TEST_ENTRY(glm_quat_rotate_atm)
   TEST_ENTRY(glm_quat_from_vecs)
+  TEST_ENTRY(glm_quat_make)
 
   TEST_ENTRY(glmc_quat_identity)
   TEST_ENTRY(glmc_quat_identity_array)
@@ -1184,6 +1409,7 @@ TEST_LIST {
   TEST_ENTRY(glmc_quat_rotate_at)
   TEST_ENTRY(glmc_quat_rotate_atm)
   TEST_ENTRY(glmc_quat_from_vecs)
+  TEST_ENTRY(glmc_quat_make)
 
   /* bezier */
   TEST_ENTRY(bezier)
@@ -1230,6 +1456,7 @@ TEST_LIST {
   TEST_ENTRY(glm_vec2_lerp)
   TEST_ENTRY(glm_vec2_complex_mul)
   TEST_ENTRY(glm_vec2_complex_div)
+  TEST_ENTRY(glm_vec2_make)
 
   TEST_ENTRY(glmc_vec2)
   TEST_ENTRY(glmc_vec2_copy)
@@ -1268,6 +1495,7 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec2_lerp)
   TEST_ENTRY(glmc_vec2_complex_mul)
   TEST_ENTRY(glmc_vec2_complex_div)
+  TEST_ENTRY(glmc_vec2_make)
 
   /* vec3 */
   TEST_ENTRY(MACRO_GLM_VEC3_ONE_INIT)
@@ -1362,6 +1590,7 @@ TEST_LIST {
   TEST_ENTRY(glm_vec3_fract)
   TEST_ENTRY(glm_vec3_hadd)
   TEST_ENTRY(glm_vec3_sqrt)
+  TEST_ENTRY(glm_vec3_make)
 
   TEST_ENTRY(glmc_vec3)
   TEST_ENTRY(glmc_vec3_copy)
@@ -1431,6 +1660,7 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec3_fract)
   TEST_ENTRY(glmc_vec3_hadd)
   TEST_ENTRY(glmc_vec3_sqrt)
+  TEST_ENTRY(glmc_vec3_make)
 
   /* vec4 */
   TEST_ENTRY(MACRO_GLM_VEC4_ONE_INIT)
@@ -1512,6 +1742,7 @@ TEST_LIST {
   TEST_ENTRY(glm_vec4_fract)
   TEST_ENTRY(glm_vec4_hadd)
   TEST_ENTRY(glm_vec4_sqrt)
+  TEST_ENTRY(glm_vec4_make)
 
   TEST_ENTRY(glmc_vec4)
   TEST_ENTRY(glmc_vec4_copy3)
@@ -1577,6 +1808,7 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec4_fract)
   TEST_ENTRY(glmc_vec4_hadd)
   TEST_ENTRY(glmc_vec4_sqrt)
+  TEST_ENTRY(glmc_vec4_make)
 
   /* ivec2 */
   TEST_ENTRY(glm_ivec2)
@@ -1681,10 +1913,22 @@ TEST_LIST {
   TEST_ENTRY(glmc_ivec4_abs)
 
   /* structs */
+  TEST_ENTRY(mat2x3s_zero_init)
+  TEST_ENTRY(mat2x3s_zero)
+  TEST_ENTRY(mat2x4s_zero_init)
+  TEST_ENTRY(mat2x4s_zero)
   TEST_ENTRY(mat3s_identity_init)
   TEST_ENTRY(mat3s_zero_init)
+  TEST_ENTRY(mat3x2s_zero_init)
+  TEST_ENTRY(mat3x2s_zero)
+  TEST_ENTRY(mat3x4s_zero_init)
+  TEST_ENTRY(mat3x4s_zero)
   TEST_ENTRY(mat4s_identity_init)
   TEST_ENTRY(mat4s_zero_init)
+  TEST_ENTRY(mat4x2s_zero_init)
+  TEST_ENTRY(mat4x2s_zero)
+  TEST_ENTRY(mat4x3s_zero_init)
+  TEST_ENTRY(mat4x3s_zero)
   TEST_ENTRY(quats_zero_init)
   TEST_ENTRY(vec3s_one_init)
   TEST_ENTRY(vec3s_zero_init)
